@@ -10,11 +10,11 @@ MongoDBx::Tiny - Simple Mongo ORM for Perl
 
 =head1 VERSION
 
-Version 0.02_03
+Version 0.02
 
 =cut
 
-our $VERSION = '0.02_03';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -134,13 +134,7 @@ sub new {
 	$class->install_database_name($opt->{database_name});
     }
     my $self = bless{},$class;
-    eval { $self->connect; };
-
-    if ($@) {
-	Carp::carp $@;
-	return;
-    }
-
+    $self->connect;
     return $self;
 }
 
